{% block details %}
<h1>Wiki</h1>
Use the `+` icon to add a new Page.<br />
On the left; the menu/hierarchy will appear as pages are added.<br />
On the right; details/options for a page will become available as you navigate the hierarchy.

{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
