{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}

{% block page_title %}{% translate "wiki" %}{% endblock %}

{% block content %}
    <div class="allianceauth-evewiki-plugin">

        {% block details %}{% endblock %}
    </div>
{% endblock %}
