<li>
    <a href="/evewiki/{{ node.path }}">{{ node.title }}</a>
    {% if node.children and node.depth < settings.hierarchy_max_display_depth %}
        <ul>
            {% for child in node.children %}
                {% include "evewiki/page_tree.html" with node=child %}
            {% endfor %}
        </ul>
    {% endif %}
</li>
